@@ -71,7 +71,7 @@ sub make_ranges {
 		}
 		return $divisions;
 	} else {
-		return unless defined $max && defined $min && defined $max;
+		return unless defined $max && defined $min && $max-$min;
 		for my $block (make_list($blocks)) {
 			my @pp     = ($block, @$param_path);
 			next if hide(@pp);
@@ -95,50 +95,44 @@ sub make_ranges {
 }
 
 sub make_divisions {
-	my ($blocks,$param_path,$min,$max,$r0,$r1) = @_;
+	my ($blocks,$param_path,$min,$max,$set) = @_;
 	return unless $blocks;
-	if(defined $min && defined $max) {
-
-	} elsif (defined $r0 && defined $r1) {
-		$min = $r0;
-		$max = $r1;
-	} else {
-		return;
-	}
+	return unless defined $max && defined $min && $max-$min;
 	my $divisions;
 	for my $block (make_list($blocks)) {
 		my @pp      = ($block, @$param_path);
 		next if hide(@pp);
-
+		
 		# positions to skip
-		my @skip    = parse_position( seek_parameter("position_skip",@pp),\@pp,$min,$max);
+		my @skip    = parse_position( seek_parameter("position_skip",@pp), \@pp, $min, $max);
 		my %skip    = map { $_=>1 } @skip;
-
+		
 		# specific positions
-		my @pos     = parse_position( seek_parameter("position",@pp),\@pp,$min,$max);
-		# positions determined with fixed or relative spacing
+		my @pos     = parse_position( seek_parameter("position",     @pp), \@pp, $min, $max);
+		
+		# positions determined with fixed spacing
 		my $spacing = parse_value(seek_parameter("spacing",@pp),$max-$min);
-
+		
 		# optional y start/end values
 		my $ystart = parse_value(seek_parameter("y0",@pp),$min,$max);
 		my $yend   = parse_value(seek_parameter("y1",@pp),$min,$max);
 		$ystart = $min if ! defined $ystart || $ystart < $min;
 		$yend   = $max if ! defined $yend || $yend > $max;
-
+		
 		$block->{spacing} = $spacing;
 		my @posauto = parse_spacing( $spacing , \@pp, $min, $max);
-		my $TOL = ($spacing||0)/1000; # float roundoff causes problems without TOL
+		
 		for my $pos (sort {$a <=> $b} uniq (@pos,@posauto)) {
-			my $skip =  $skip{$pos} || $pos < $ystart - $TOL || $pos > $yend + $TOL;
+			my $skip =  $skip{$pos} || $pos < $ystart || $pos > $yend;
 			printdebug_group("axis","line", $skip?" ":"+",$spacing,$pos,$block->{color});
 			next if $skip;
 	    push @{$divisions->{$spacing || 0}{$pos}}, $block;
 		}
 	}
-
+	
 	my $sorted_divisions = [];
 	my $seen_division;
-
+	
 	for my $spacing (sort {$b <=> $a} keys %$divisions) {
 		for my $pos (sort {$a <=> $b} keys %{$divisions->{$spacing}}) {
 	    # if this division is generated with non-zero spacing (i.e. automatic)
@@ -149,7 +143,7 @@ sub make_divisions {
 																	pos     => $pos,
 																	block   => $divisions->{$spacing}{$pos}[0]};
 		}
-	}
+	}    
 	# division blocks
 	return $sorted_divisions;
 }
@@ -168,7 +162,6 @@ sub parse_position {
 sub parse_spacing {
 	my ($str,$pp,$min,$max) = @_;
 	return unless defined $str;
-
 	my $spacing = parse_value($str,$max-$min);
 
 	if((my $num_axes = ($max-$min) / $spacing) > 1000) {
@@ -182,10 +175,9 @@ sub parse_spacing {
 	$yend      = parse_value($yend,  $max-$min);
 
 	my @ypos;
-	my $TOL = $spacing/1000; # float roundoff causes problems without TOL
-	for (my $y = $min; $y <= $max + $TOL; $y += $spacing) {
-		next if $y < $ystart - $TOL;
-		last if $y > $yend + $TOL;
+	for (my $y = $min; $y <= $max; $y += $spacing) {
+		next if $y < $ystart;
+		last if $y > $yend;
 		push @ypos, $y;
 	}
 	return @ypos;
