@@ -35,7 +35,7 @@ use warnings;
 
 use base 'Exporter';
 our @EXPORT = qw(
-is_on_ideogram
+
 );
 
 use Carp qw( carp confess croak );
@@ -177,9 +177,7 @@ sub parse_chromosomes {
 		      #printdumper(@chr_in_c_found);
 		      for my $c (@chr_in_c_found) {
 			  next if $c->{reject};
-			  # now both RX and literals will be processed
-			  # this is experimental 0.67-pre8
-			  if (1 || ! $c->{rx}) {
+			  if (! $c->{rx}) {
 			      my $str = $c->{chr};
 			      if ($c->{reject}) {
 				  $str = "-$str";
@@ -353,8 +351,6 @@ sub parse_chromosomes_record {
   my $str = shift;
   my $default_delim  = "[:=]";
   my ($chr,$runlist) = split(Circos::Configuration::fetch_configuration("list_field_delim") || $default_delim ,$str);
-  $runlist = Circos::Configuration::parse_conf_fn($runlist) if defined $runlist;
-  #printinfo($runlist);
   my ($tag,$reject,$rx);
   ( $reject, $chr, $tag ) = $chr =~ /([!-])?(.+?)(?:\[([^\[\]]+)\])?$/;
   $reject = $reject ? 1 : 0;
@@ -392,32 +388,4 @@ sub report_chromosomes {
   }
 }
 
-# Quickly check whether a point appears on a drawn portion of
-# a chromosome. An ideogram must exist and have a cover that
-# intersects with the data point coordinate. Not using Set::IntSpan
-# here because it is too slow.
-sub is_on_ideogram {
-	my $datum       = shift;
-	my $on_ideogram = 1;
-	for my $point ( @{$datum->{data}}) {
-		my $chr       = $point->{chr};
-		my $ideograms = Circos::get_ideograms_by_name($chr);
-		# If the chromosome is not being displayed, it has no ideogram.
-		return if ! defined $ideograms;
-		my ($start,$end) = ($point->{start},$point->{end});
-		for my $ideogram (@$ideograms) {
-			for my $cover (@{$ideogram->{covers}}) {
-				my ($cstart,$cend) = ($cover->{set}->min,$cover->{set}->max);
-				if($cstart > $end || $cend < $start) {
-					# not on ideogram
-				} else {
-					return 1;
-				}
-			}
-		}
-	}
-	# none of the points coordinates fell inside any ideogram cover
-	return;
-}
-
 1;
